# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"hello": "00-module.ipynb"}

modules = ["module.py"]

doc_url = "https://vasya_pupkin.github.io/lib_example_12345/"

git_url = "https://github.com/vasya_pupkin/lib_example_12345/tree/master/"

def custom_doc_links(name): return None
